import React from 'react';
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { ReactQueryDevtools } from '@tanstack/react-query-devtools';
import { getConfig } from './config';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const defaultQueryClient = new QueryClient({
  defaultOptions: {
    queries: getConfig().defaultOptions
  }
});

/**
 * Provider component for SWD Query
 * @param {Object} props - Component props
 * @param {React.ReactNode} props.children - Child components
 * @param {QueryClient} [props.queryClient] - Custom query client
 * @param {boolean} [props.enableDevTools] - Enable React Query dev tools
 */

const SWDQueryProvider = _ref => {
  let {
    children,
    queryClient = defaultQueryClient,
    enableDevTools = false
  } = _ref;
  return /*#__PURE__*/_jsxs(QueryClientProvider, {
    client: queryClient,
    children: [children, enableDevTools && /*#__PURE__*/_jsx(ReactQueryDevtools, {
      initialIsOpen: false
    })]
  });
};
export default SWDQueryProvider;