﻿import React, { useState, useContext } from "react";
import axios from "axios";

export const AuthContext = React.createContext();
export const useAuth = () => useContext(AuthContext);

export const AuthProvider = ({
    children,
    loginUrl = "/bff/login", 
    logoutUrl = "/bff/logout",
    loginreturnUrl = "",
    logoutreturnUrl = "",
    basepath = ""

}) => {

    const [user, setUser] = useState();

    const login = () => {
        // Redirect to loginUrl with returnUrl
        let url = loginUrl;
        // Append returnUrl only if provided
        if (loginreturnUrl) {
            url = `${loginUrl}?returnUrl=${encodeURIComponent(loginreturnUrl)}`;
        }
        // Redirect to the login URL
        window.location.href = `${basepath}${url}`;
    };

    const logout = () => {
        // Use the passed logoutUrl and append returnUrl
        window.location = `${basepath}${logoutUrl}&returnUrl=${encodeURIComponent(logoutreturnUrl)}`;
    };

    const getUser = async () => {
        const response = await axios.get(`${basepath}/bff/user`, {
            headers: {
                Accept: "application/json",
                "Content-Type": "application/json",
                "X-CSRF": 1,
            },
        });

        const obj = {};
        response?.data.forEach(x => {
            obj[x?.type] = x?.value;
        });

        setUser(obj);

        return response;
    };

    return (
        <AuthContext.Provider
            value={{
                user,
                setUser,
                login,
                logout,
                getUser
            }}
        >
            {children}
        </AuthContext.Provider>
    );
};
