import React from 'react';
import { QueryClient, QueryClientProvider } from '@tanstack/react-query';
import { ReactQueryDevtools } from '@tanstack/react-query-devtools';
import { getConfig } from '../config';

const defaultQueryClient = new QueryClient({
  defaultOptions: {
    queries: getConfig().defaultOptions,
  },
});

/**
 * Provider component for SWD Query
 * @param {Object} props - Component props
 * @param {React.ReactNode} props.children - Child components
 * @param {QueryClient} [props.queryClient] - Custom query client
 * @param {boolean} [props.enableDevTools] - Enable React Query dev tools
 */

const SWDQueryProvider = ({ 
  children, 
  queryClient = defaultQueryClient,
  enableDevTools = false 
}) => {
  return (
    <QueryClientProvider client={queryClient}>
      {children}
      {enableDevTools && <ReactQueryDevtools initialIsOpen={false} />}
    </QueryClientProvider>
  );
};

export default SWDQueryProvider;
