import { useMutation, useQueryClient } from '@tanstack/react-query';
import { axiosInstance } from '../config';

const usePost = (queryKey, queryUrl, options = {}) => {
  const queryClient = useQueryClient();

  const mutationFn = async (data) => {
    const response = await axiosInstance.post(queryUrl, data);
    
    if (!response) {
      throw new Error("No response received.");
    }
    return response.data;
  };

  return useMutation({
    mutationFn,
    onSuccess: () => {
      queryClient.invalidateQueries({ queryKey });
    },
    networkMode: "always",
    ...options,
  });
};

export default usePost;
